# Generated by Django 3.1.6 on 2023-02-13 02:37

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bcmr', '0002_authtoken'),
    ]

    operations = [
        migrations.AddField(
            model_name='registry',
            name='owner',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='registries', to='bcmr.authtoken'),
        ),
        migrations.AddField(
            model_name='token',
            name='owner',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='tokens', to='bcmr.authtoken'),
        ),
    ]
