# Generated by Django 3.1.6 on 2023-02-14 04:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bcmr', '0003_auto_20230213_0237'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='authtoken',
            options={'verbose_name_plural': 'Auth Tokens'},
        ),
        migrations.AlterModelOptions(
            name='registry',
            options={'ordering': ('name',), 'verbose_name_plural': 'Registries'},
        ),
    ]
